﻿namespace CachedRepository.DataAccess.UserProfiles
{
	using CachedRepository.Models;
	using Microsoft.Practices.Unity;
	using System;
	using System.Collections.Generic;

	public class CachedUserProfileRepository : IUserProfileRepository
	{
		private static readonly IDictionary<int, UserProfile> _cache = new Dictionary<int, UserProfile>();
		private readonly IUserProfileRepository _repository;

		public CachedUserProfileRepository([Dependency("DirectDataAccess")] IUserProfileRepository repository)
		{
			this._repository = repository;
		}

		public UserProfile Get(int id)
		{

			Console.WriteLine(string.Format("Getting user profile {0} from cache", id));
			UserProfile profile = null;

			if (!_cache.TryGetValue(id, out profile))
			{
				Console.WriteLine(string.Format("User profile {0} was not found in the cache.", id));
				profile = this._repository.Get(id);
				_cache.Add(profile.Id, profile);
			}

			return profile;

		}

		public void Update(UserProfile profile)
		{
			this._repository.Update(profile);
			_cache.Remove(profile.Id);
		}
	}
}
